@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2024 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef _FILESETTINGS_H_
-#define _FILESETTINGS_H_
+#ifndef FILESETTINGS_H
+#define FILESETTINGS_H
 
 #include "filesettingsbase.h"
 
@@ -29,13 +29,13 @@ public:
 	FileSettings(QString directory);
 	virtual ~FileSettings();
 
-	virtual bool existSettingsFor(QString filename);
+	virtual bool existSettingsFor(QString filename, int type);
 
-	virtual void loadSettingsFor(QString filename, MediaSettings & mset);
+	virtual void loadSettingsFor(QString filename, int type, MediaSettings & mset, int player);
 
-	virtual void saveSettingsFor(QString filename, MediaSettings & mset);
+	virtual void saveSettingsFor(QString filename, int type, MediaSettings & mset, int player);
 
-	static QString filenameToGroupname(const QString & filename);
+	static QString filenameToGroupname(const QString & filename, int type);
 
 private:
 	QSettings * my_settings;
