@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2024 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@ class FixSubtitles
 {
 public:
 	enum ErrorCode { NoError = 0, ReadError = 1, WriteError = 2 };
-	static ErrorCode fix(const QString & in_file, const QString & out_file = QString::null);
+	static ErrorCode fix(const QString & in_file, const QString & out_file = QString());
 };
 
 #endif
