@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2024 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,7 +24,9 @@
 #include "mediadata.h"
 #include "config.h"
 
+#if QT_VERSION < 0x060000
 class QStringList;
+#endif
 
 class MplayerProcess : public PlayerProcess
 {
@@ -38,15 +40,17 @@ public:
 
 	// Command line options
 	void setMedia(const QString & media, bool is_playlist = false);
-	void setFixedOptions();
+	void setPredefinedOptions();
+	void disableConfig();
 	void disableInput();
 	void setOption(const QString & option_name, const QVariant & value = QVariant());
 	void addUserOption(const QString & option);
 	void addVF(const QString & filter_name, const QVariant & value = QVariant());
 	void addAF(const QString & filter_name, const QVariant & value = QVariant());
 	void addStereo3DFilter(const QString & in, const QString & out);
-	void setSubStyles(const AssStyles & styles, const QString & assStylesFile = QString::null);
+	void setSubStyles(const AssStyles & styles, const QString & assStylesFile = QString());
 	void setSubEncoding(const QString & codepage, const QString & enca_lang);
+	void setVideoEqualizerOptions(int contrast, int brightness, int hue, int saturation, int gamma, bool soft_eq);
 
 	// Slave commands
 	void quit();
@@ -65,13 +69,16 @@ public:
 	void frameStep();
 	void frameBackStep();
 	void showOSDText(const QString & text, int duration, int level);
-	void showFilenameOnOSD();
+	void showFilenameOnOSD(int duration = 2000);
+	void showMediaInfoOnOSD();
 	void showTimeOnOSD();
+
 	void setContrast(int value);
 	void setBrightness(int value);
 	void setHue(int value);
 	void setSaturation(int value);
 	void setGamma(int value);
+
 	void setChapter(int ID);
 	void nextChapter();
 	void previousChapter();
@@ -88,7 +95,7 @@ public:
 	void enableExtrastereo(bool b);
 	void enableVolnorm(bool b, const QString & option);
 #ifdef MPV_SUPPORT
-	void enableEarwax(bool b) {};
+	void enableEarwax(bool /*b*/) {};
 #endif
 	void setAudioEqualizer(AudioEqualizerList);
 	void setAudioDelay(double delay);
@@ -103,6 +110,7 @@ public:
 #endif
 	void setTitle(int ID);
 	void changeVF(const QString & filter, bool enable, const QVariant & option = QVariant());
+	void changeAF(const QString & filter, bool enable, const QVariant & option = QVariant());
 	void changeStereo3DFilter(bool enable, const QString & in, const QString & out);
 #if DVDNAV_SUPPORT
 	void discSetMousePos(int x, int y);
@@ -119,17 +127,23 @@ public:
 	void setOSDFractions(bool) {};
 	void setChannelsFile(const QString &) {};
 
-	void enableScreenshots(const QString & dir, const QString & templ = QString::null, const QString & format = QString::null);
+	void enableScreenshots(const QString & dir, const QString & templ = QString(), const QString & format = QString());
 
 #ifdef CAPTURE_STREAM
 	void setCaptureDirectory(const QString & dir);
 #endif
 
+	void enableOSDInCommands(bool) {};
+	bool isOSDInCommandsEnabled() { return true; };
+
 protected slots:
 	void parseLine(QByteArray ba);
 	void processFinished(int exitCode, QProcess::ExitStatus exitStatus);
 	void gotError(QProcess::ProcessError);
 
+protected:
+	virtual void initializeOptionVars();
+
 private:
 	bool notified_mplayer_is_running;
 	bool received_end_of_file;
@@ -150,6 +164,11 @@ private:
 	bool audio_info_changed;
 #endif
 
+#if NOTIFY_VIDEO_CHANGES
+	Tracks videos;
+	bool video_info_changed;
+#endif
+
 	int dvd_current_title;
 	int br_current_title;
 };
