@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2024 Ricardo Villalba <ricardo@smplayer.info>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -45,9 +45,13 @@
 #include "retrieveyoutubeurl.h"
 #endif
 
-//#define USE_CONFIG_VERSION
+#ifdef GLOBALSHORTCUTS
+#include "globalshortcuts/globalshortcuts.h"
+#endif
+
+#define USE_CONFIG_VERSION
 #ifdef USE_CONFIG_VERSION
-#define CURRENT_CONFIG_VERSION 4
+#define CURRENT_CONFIG_VERSION 5
 #endif
 
 using namespace Global;
@@ -81,11 +85,10 @@ void Preferences::reset() {
 
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 	mplayer_bin= "mpv/mpv.exe";
-	if (QSysInfo::WindowsVersion < QSysInfo::WV_VISTA) {
+	if (QSysInfo::WindowsVersion < QSysInfo::WV_WINDOWS7) {
 		mplayer_bin= "mplayer/mplayer.exe";
 	}
 #else
-	//mplayer_bin = "mplayer";
 	mplayer_bin = "mpv";
 #endif
 
@@ -98,16 +101,16 @@ void Preferences::reset() {
 	screenshot_format = "jpg";
 #endif
 	screenshot_directory="";
-#ifdef PORTABLE_APP
-	screenshot_directory= "./screenshots";
-#else
+//#ifdef PORTABLE_APP
+//	screenshot_directory= "./screenshots";
+//#else
 	#if QT_VERSION < 0x040400
 	QString default_screenshot_path = Paths::configPath() + "/screenshots";
 	if (QFile::exists(default_screenshot_path)) {
 		screenshot_directory = default_screenshot_path;
 	}
 	#endif
-#endif
+//#endif
 
 #ifdef CAPTURE_STREAM
 	capture_directory = "";
@@ -115,10 +118,15 @@ void Preferences::reset() {
 
 	remember_media_settings = true;
 	remember_time_pos = true;
-	remember_stream_settings = true;
+	remember_stream_settings = false;
 
+#if SIMPLE_TRACK_SELECTION
+	alang = "";
+	slang = "";
+#else
 	audio_lang = "";
 	subtitle_lang = "";
+#endif
 
 	use_direct_rendering = false;
 	use_double_buffer = true;
@@ -131,18 +139,16 @@ void Preferences::reset() {
 	add_blackborders_on_fullscreen = false;
 #endif
 
-#ifdef Q_OS_WIN
-	#ifdef SCREENSAVER_OFF
-	turn_screensaver_off = false;
-	#endif
-	#ifdef AVOID_SCREENSAVER
-	avoid_screensaver = true;
-	#endif
-#else
+#ifdef SCREENSAVER_OFF
 	disable_screensaver = true;
 #endif
+#if defined(Q_OS_WIN) && defined(AVOID_SCREENSAVER)
+	avoid_screensaver = true;
+#endif
+
+#ifdef OS_UNIX_NOT_MAC
+	wayland_workarounds = true;
 
-#ifndef Q_OS_WIN
 	vdpau.ffh264vdpau = true;
 	vdpau.ffmpeg12vdpau = true;
 	vdpau.ffwmv3vdpau = true;
@@ -160,7 +166,7 @@ void Preferences::reset() {
 	softvol_max = 110; // 110 = default value in mplayer
 	use_scaletempo = Detect;
 	use_hwac3 = false;
-	use_audio_equalizer = true;
+	use_audio_equalizer = false;
 
 	global_volume = true;
 	volume = 50;
@@ -169,6 +175,9 @@ void Preferences::reset() {
 	global_audio_equalizer = true;
 	audio_equalizer << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0; // FIXME: use initial_audio_equalizer (but it's set later)
 
+	global_speed = false;
+	speed = 1.0;
+
 	autosync = false;
 	autosync_factor = 100;
 
@@ -181,10 +190,12 @@ void Preferences::reset() {
 	osd = Seek;
 	osd_scale = 1;
 	subfont_osd_scale = 3;
-	osd_delay = 2200;
+	osd_delay = 5000;
 #ifdef MPV_SUPPORT
 	osd_fractions = false;
 #endif
+	osd_bar_pos = 80;
+	osd_show_filename_duration = 2000;
 
 	file_settings_method = "hash"; // Possible values: normal & hash
 
@@ -363,10 +374,14 @@ void Preferences::reset() {
 
 	show_tag_in_window_title = true;
 
-	time_to_kill_mplayer = 1000;
+	time_to_kill_mplayer = 5000;
 
 #ifdef MPRIS2
+	#ifdef Q_OS_LINUX
 	use_mpris2 = true;
+	#else
+	use_mpris2 = false;
+	#endif
 #endif
 
 #ifdef MPV_SUPPORT
@@ -376,6 +391,14 @@ void Preferences::reset() {
 	mplayer_osd_media_info = "";
 #endif
 
+#ifdef MPV_SUPPORT
+	emulate_mplayer_ab_section = false;
+#endif
+
+	use_native_open_dialog = true;
+
+	disable_player_config = true;
+
 
     /* *********
        GUI stuff
@@ -402,6 +425,11 @@ void Preferences::reset() {
 
 #ifdef GLOBALSHORTCUTS
 	use_global_shortcuts = false;
+	global_shortcuts_grabbed_keys = GlobalShortcuts::MediaPlay | GlobalShortcuts::MediaStop |
+                                    GlobalShortcuts::MediaPrevious | GlobalShortcuts::MediaNext |
+                                    GlobalShortcuts::MediaPause | GlobalShortcuts::MediaRecord |
+                                    GlobalShortcuts::VolumeMute | GlobalShortcuts::VolumeDown |
+                                    GlobalShortcuts::VolumeUp;
 #endif
 
 #if DVDNAV_SUPPORT
@@ -420,7 +448,7 @@ void Preferences::reset() {
 
 	drag_function = MoveWindow;
 
-	seeking1 = 10;
+	seeking1 = 5;
 	seeking2 = 60;
 	seeking3 = 10*60;
 	seeking4 = 30;
@@ -432,7 +460,7 @@ void Preferences::reset() {
 #if SEEKBAR_RESOLUTION
 	relative_seeking = false;
 #endif
-	precise_seeking = true;
+	precise_seeking = false;
 
 	reset_stop = false;
 	delay_left_click = false;
@@ -474,7 +502,11 @@ void Preferences::reset() {
 	hide_video_window_on_audio_files = true;
 #endif
 
+#ifdef Q_OS_WIN
+	report_mplayer_crashes = false;
+#else
 	report_mplayer_crashes = true;
+#endif
 
 #if REPORT_OLD_MPLAYER
 	reported_mplayer_is_old = false;
@@ -483,6 +515,9 @@ void Preferences::reset() {
 	auto_add_to_playlist = true;
 	media_to_add_to_playlist = NoFiles;
 
+	use_player_shortcuts_in_playlist = false;
+	dockable_playlist = true;
+
 #if LOGO_ANIMATION
 	animated_logo = true;
 #endif
@@ -505,15 +540,18 @@ void Preferences::reset() {
 
 #ifdef MPV_SUPPORT
 	streaming_type = StreamingAuto;
+	ytdl_quality = "";
 #else
 	streaming_type = StreamingYT;
 #endif
 #ifdef YOUTUBE_SUPPORT
-	yt_quality = RetrieveYoutubeUrl::MP4_720p;
-	//yt_user_agent = "Mozilla/5.0 (X11; Linux x86_64; rv:5.0.1) Gecko/20100101 Firefox/5.0.1";
+	yt_resolution = RetrieveYoutubeUrl::R720p;
 	yt_user_agent = "";
-	yt_use_https_main = false;
-	yt_use_https_vi = false;
+	yt_ytdl_bin = "";
+	yt_override_format = "";
+	yt_use_dash = true;
+	yt_use_60fps = true;
+	yt_use_av1 = false;
 #endif
 
 	// Proxy
@@ -563,8 +601,10 @@ void Preferences::reset() {
 	initial_audio_channels = MediaSettings::ChDefault;
 	initial_stereo_mode = MediaSettings::Stereo;
 
-	initial_audio_track = 1;
-	initial_subtitle_track = 1;
+#if SELECT_TRACKS_ON_STARTUP
+	initial_audio_track = 0;
+	initial_subtitle_track = 0;
+#endif
 
 
     /* ************
@@ -575,7 +615,7 @@ void Preferences::reset() {
 	mplayer_user_supplied_version = -1;
 #ifdef MPLAYER2_SUPPORT
 	mplayer_is_mplayer2 = false;
-	mplayer2_detected_version = QString::null;
+	mplayer2_detected_version = QString();
 #endif
 
 
@@ -664,8 +704,13 @@ void Preferences::save() {
 	set->setValue("remember_time_pos", remember_time_pos);
 	set->setValue("remember_stream_settings", remember_stream_settings);
 
+#if SIMPLE_TRACK_SELECTION
+	set->setValue("alang", alang);
+	set->setValue("slang", slang);
+#else
 	set->setValue("audio_lang", audio_lang);
 	set->setValue("subtitle_lang", subtitle_lang);
+#endif
 
 	set->setValue("use_direct_rendering", use_direct_rendering);
 	set->setValue("use_double_buffer", use_double_buffer);
@@ -677,18 +722,16 @@ void Preferences::save() {
 	set->setValue("add_blackborders_on_fullscreen", add_blackborders_on_fullscreen);
 #endif
 
-#ifdef Q_OS_WIN
-	#ifdef SCREENSAVER_OFF
-	set->setValue("turn_screensaver_off", turn_screensaver_off);
-	#endif
-	#ifdef AVOID_SCREENSAVER
-	set->setValue("avoid_screensaver", avoid_screensaver);
-	#endif
-#else
+#ifdef SCREENSAVER_OFF
 	set->setValue("disable_screensaver", disable_screensaver);
 #endif
+#if defined(Q_OS_WIN) && defined(AVOID_SCREENSAVER)
+	set->setValue("avoid_screensaver", avoid_screensaver);
+#endif
+
+#ifdef OS_UNIX_NOT_MAC
+	set->setValue("wayland_workarounds", wayland_workarounds);
 
-#ifndef Q_OS_WIN
 	set->setValue("vdpau_ffh264vdpau", vdpau.ffh264vdpau);
 	set->setValue("vdpau_ffmpeg12vdpau", vdpau.ffmpeg12vdpau);
 	set->setValue("vdpau_ffwmv3vdpau", vdpau.ffwmv3vdpau);
@@ -711,6 +754,9 @@ void Preferences::save() {
 	set->setValue("global_audio_equalizer", global_audio_equalizer);
 	set->setValue("audio_equalizer", audio_equalizer);
 
+	set->setValue("global_speed", global_speed);
+	set->setValue("speed", speed);
+
 	set->setValue("autosync", autosync);
 	set->setValue("autosync_factor", autosync_factor);
 
@@ -727,6 +773,8 @@ void Preferences::save() {
 #ifdef MPV_SUPPORT
 	set->setValue("osd_fractions", osd_fractions);
 #endif
+	set->setValue("osd_bar_pos", osd_bar_pos);
+	set->setValue("osd_show_filename_duration", osd_show_filename_duration);
 
 	set->setValue("file_settings_method", file_settings_method);
 
@@ -901,7 +949,7 @@ void Preferences::save() {
 
 	set->setValue("show_tag_in_window_title", show_tag_in_window_title);
 
-	set->setValue("time_to_kill_mplayer", time_to_kill_mplayer);
+	set->setValue("time_to_kill_player", time_to_kill_mplayer);
 
 #ifdef MPRIS2
 	set->setValue("use_mpris2", use_mpris2);
@@ -914,6 +962,14 @@ void Preferences::save() {
 	set->setValue("mplayer_osd_media_info", mplayer_osd_media_info);
 #endif
 
+#ifdef MPV_SUPPORT
+	set->setValue("emulate_mplayer_ab_section", emulate_mplayer_ab_section);
+#endif
+
+	set->setValue("use_native_open_dialog", use_native_open_dialog);
+
+	set->setValue("disable_player_config", disable_player_config);
+
 	set->endGroup(); // advanced
 
 
@@ -940,6 +996,7 @@ void Preferences::save() {
 
 #ifdef GLOBALSHORTCUTS
 	set->setValue("use_global_shortcuts", use_global_shortcuts);
+	set->setValue("global_shortcuts_grabbed_keys", global_shortcuts_grabbed_keys);
 #endif
 
 	set->setValue("mouse_left_click_function", mouse_left_click_function);
@@ -1002,7 +1059,7 @@ void Preferences::save() {
 	set->setValue("hide_video_window_on_audio_files", hide_video_window_on_audio_files);
 #endif
 
-	set->setValue("report_mplayer_crashes", report_mplayer_crashes);
+	set->setValue("report_player_crashes", report_mplayer_crashes);
 
 #if REPORT_OLD_MPLAYER
 	set->setValue("reported_mplayer_is_old", reported_mplayer_is_old);
@@ -1010,6 +1067,8 @@ void Preferences::save() {
 
 	set->setValue("auto_add_to_playlist", auto_add_to_playlist);
 	set->setValue("media_to_add_to_playlist", media_to_add_to_playlist);
+	set->setValue("use_player_shortcuts_in_playlist", use_player_shortcuts_in_playlist);
+	set->setValue("dockable_playlist", dockable_playlist);
 
 #if LOGO_ANIMATION
 	set->setValue("animated_logo", animated_logo);
@@ -1037,13 +1096,19 @@ void Preferences::save() {
 
 	set->beginGroup("streaming");
 	set->setValue("streaming_type", streaming_type);
+#ifdef MPV_SUPPORT
+	set->setValue("ytdl_quality", ytdl_quality);
+#endif
 
 	#ifdef YOUTUBE_SUPPORT
 	set->beginGroup("streaming/youtube");
-	set->setValue("quality", yt_quality);
-	set->setValue("user_agent", yt_user_agent);
-	set->setValue("yt_use_https_main", yt_use_https_main);
-	set->setValue("yt_use_https_vi", yt_use_https_vi);
+	set->setValue("resolution", yt_resolution);
+	set->setValue("preferred_user_agent", yt_user_agent);
+	set->setValue("ytdl_bin", yt_ytdl_bin);
+	set->setValue("override_format", yt_override_format);
+	set->setValue("use_dash", yt_use_dash);
+	set->setValue("use_60fps", yt_use_60fps);
+	set->setValue("use_av1", yt_use_av1);
 	set->endGroup();
 	#endif
 	set->endGroup(); // streaming
@@ -1107,8 +1172,10 @@ void Preferences::save() {
 	set->setValue("audio_channels", initial_audio_channels);
 	set->setValue("initial_stereo_mode", initial_stereo_mode);
 
-	set->setValue("initial_audio_track", initial_audio_track);
-	set->setValue("initial_subtitle_track", initial_subtitle_track);
+#if SELECT_TRACKS_ON_STARTUP
+	set->setValue("preferred_audio_track", initial_audio_track);
+	set->setValue("preferred_subtitle_track", initial_subtitle_track);
+#endif
 
 	set->endGroup(); // defaults
 
@@ -1234,12 +1301,17 @@ void Preferences::load() {
 	remember_time_pos = set->value("remember_time_pos", remember_time_pos).toBool();
 	remember_stream_settings = set->value("remember_stream_settings", remember_stream_settings).toBool();
 
+#if SIMPLE_TRACK_SELECTION
+	alang = set->value("alang", alang).toString();
+	slang = set->value("slang", slang).toString();
+#else
 	audio_lang = set->value("audio_lang", audio_lang).toString();
 	subtitle_lang = set->value("subtitle_lang", subtitle_lang).toString();
+#endif
 
 	use_direct_rendering = set->value("use_direct_rendering", use_direct_rendering).toBool();
 	use_double_buffer = set->value("use_double_buffer", use_double_buffer).toBool();
-	
+
 	use_soft_video_eq = set->value("use_soft_video_eq", use_soft_video_eq).toBool();
 	use_slices = set->value("use_slices", use_slices ).toBool();
 	autoq = set->value("autoq", autoq).toInt();
@@ -1248,18 +1320,16 @@ void Preferences::load() {
 	add_blackborders_on_fullscreen = set->value("add_blackborders_on_fullscreen", add_blackborders_on_fullscreen).toBool();
 #endif
 
-#ifdef Q_OS_WIN
-	#ifdef SCREENSAVER_OFF
-	turn_screensaver_off = set->value("turn_screensaver_off", turn_screensaver_off).toBool();
-	#endif
-	#ifdef AVOID_SCREENSAVER
-	avoid_screensaver = set->value("avoid_screensaver", avoid_screensaver).toBool();
-	#endif
-#else
+#ifdef SCREENSAVER_OFF
 	disable_screensaver = set->value("disable_screensaver", disable_screensaver).toBool();
 #endif
+#if defined(Q_OS_WIN) && defined(AVOID_SCREENSAVER)
+	avoid_screensaver = set->value("avoid_screensaver", avoid_screensaver).toBool();
+#endif
+
+#ifdef OS_UNIX_NOT_MAC
+	wayland_workarounds = set->value("wayland_workarounds", wayland_workarounds).toBool();
 
-#ifndef Q_OS_WIN
 	vdpau.ffh264vdpau = set->value("vdpau_ffh264vdpau", vdpau.ffh264vdpau).toBool();
 	vdpau.ffmpeg12vdpau = set->value("vdpau_ffmpeg12vdpau", vdpau.ffmpeg12vdpau).toBool();
 	vdpau.ffwmv3vdpau = set->value("vdpau_ffwmv3vdpau", vdpau.ffwmv3vdpau).toBool();
@@ -1282,6 +1352,9 @@ void Preferences::load() {
 	global_audio_equalizer = set->value("global_audio_equalizer", global_audio_equalizer).toBool();
 	audio_equalizer = set->value("audio_equalizer", audio_equalizer).toList();
 
+	global_speed = set->value("global_speed", global_speed).toBool();
+	speed = set->value("speed", speed).toDouble();
+
 	autosync = set->value("autosync", autosync).toBool();
 	autosync_factor = set->value("autosync_factor", autosync_factor).toInt();
 
@@ -1298,6 +1371,8 @@ void Preferences::load() {
 #ifdef MPV_SUPPORT
 	osd_fractions = set->value("osd_fractions", osd_fractions).toBool();
 #endif
+	osd_bar_pos = set->value("osd_bar_pos", osd_bar_pos).toInt();
+	osd_show_filename_duration = set->value("osd_show_filename_duration", osd_show_filename_duration).toInt();
 
 	file_settings_method = set->value("file_settings_method", file_settings_method).toString();
 
@@ -1476,7 +1551,7 @@ void Preferences::load() {
 
 	show_tag_in_window_title = set->value("show_tag_in_window_title", show_tag_in_window_title).toBool();
 
-	time_to_kill_mplayer = set->value("time_to_kill_mplayer", time_to_kill_mplayer).toInt();
+	time_to_kill_mplayer = set->value("time_to_kill_player", time_to_kill_mplayer).toInt();
 
 #ifdef MPRIS2
 	use_mpris2 = set->value("use_mpris2", use_mpris2).toBool();
@@ -1489,6 +1564,14 @@ void Preferences::load() {
 	mplayer_osd_media_info = set->value("mplayer_osd_media_info", mplayer_osd_media_info).toString();
 #endif
 
+#ifdef MPV_SUPPORT
+	emulate_mplayer_ab_section = set->value("emulate_mplayer_ab_section", emulate_mplayer_ab_section).toBool();
+#endif
+
+	use_native_open_dialog = set->value("use_native_open_dialog", use_native_open_dialog).toBool();
+
+	disable_player_config = set->value("disable_player_config", disable_player_config).toBool();
+
 	set->endGroup(); // advanced
 
 
@@ -1515,6 +1598,7 @@ void Preferences::load() {
 
 #ifdef GLOBALSHORTCUTS
 	use_global_shortcuts = set->value("use_global_shortcuts", use_global_shortcuts).toBool();
+	global_shortcuts_grabbed_keys = set->value("global_shortcuts_grabbed_keys", global_shortcuts_grabbed_keys).toInt();
 #endif
 
 	mouse_left_click_function = set->value("mouse_left_click_function", mouse_left_click_function).toString();
@@ -1580,7 +1664,7 @@ void Preferences::load() {
 	hide_video_window_on_audio_files = set->value("hide_video_window_on_audio_files", hide_video_window_on_audio_files).toBool();
 #endif
 
-	report_mplayer_crashes = set->value("report_mplayer_crashes", report_mplayer_crashes).toBool();
+	report_mplayer_crashes = set->value("report_player_crashes", report_mplayer_crashes).toBool();
 
 #if REPORT_OLD_MPLAYER
 	reported_mplayer_is_old = set->value("reported_mplayer_is_old", reported_mplayer_is_old).toBool();
@@ -1588,6 +1672,8 @@ void Preferences::load() {
 
 	auto_add_to_playlist = set->value("auto_add_to_playlist", auto_add_to_playlist).toBool();
 	media_to_add_to_playlist = (AutoAddToPlaylistFilter) set->value("media_to_add_to_playlist", media_to_add_to_playlist).toInt();
+	use_player_shortcuts_in_playlist = set->value("use_player_shortcuts_in_playlist", use_player_shortcuts_in_playlist).toBool();
+	dockable_playlist = set->value("dockable_playlist", dockable_playlist).toBool();
 
 #if LOGO_ANIMATION
 	animated_logo = set->value("animated_logo", animated_logo).toBool();
@@ -1615,14 +1701,21 @@ void Preferences::load() {
 
 	set->beginGroup("streaming");
 	streaming_type = set->value("streaming_type", streaming_type).toInt();
+#ifdef MPV_SUPPORT
+	ytdl_quality = set->value("ytdl_quality", ytdl_quality).toString();
+#endif
 
 	#ifdef YOUTUBE_SUPPORT
 	set->beginGroup("streaming/youtube");
-	yt_quality = set->value("quality", yt_quality).toInt();
-	yt_user_agent = set->value("user_agent", yt_user_agent).toString();
-	yt_use_https_main = set->value("yt_use_https_main", yt_use_https_main).toBool();
-	yt_use_https_vi = set->value("yt_use_https_vi", yt_use_https_vi).toBool();
+	yt_resolution = set->value("resolution", yt_resolution).toInt();
+	yt_user_agent = set->value("preferred_user_agent", yt_user_agent).toString();
+	yt_ytdl_bin = set->value("ytdl_bin", yt_ytdl_bin).toString();
+	yt_override_format = set->value("override_format", yt_override_format).toString();
+	yt_use_dash = set->value("use_dash", yt_use_dash).toBool();
+	yt_use_60fps = set->value("use_60fps", yt_use_60fps).toBool();
+	yt_use_av1 = set->value("use_av1", yt_use_av1).toBool();
 	set->endGroup();
+	RetrieveYoutubeUrl::setYtdlBin(yt_ytdl_bin);
 	#endif
 	set->endGroup(); // streaming
 
@@ -1682,8 +1775,10 @@ void Preferences::load() {
 	initial_audio_channels = set->value("audio_channels", initial_audio_channels).toInt();
 	initial_stereo_mode = set->value("initial_stereo_mode", initial_stereo_mode).toInt();
 
-	initial_audio_track = set->value("initial_audio_track", initial_audio_track).toInt();
-	initial_subtitle_track = set->value("initial_subtitle_track", initial_subtitle_track).toInt();
+#if SELECT_TRACKS_ON_STARTUP
+	initial_audio_track = set->value("preferred_audio_track", initial_audio_track).toInt();
+	initial_subtitle_track = set->value("preferred_subtitle_track", initial_subtitle_track).toInt();
+#endif
 
 	set->endGroup(); // defaults
 
@@ -1806,11 +1901,21 @@ void Preferences::load() {
 			frame_drop = false;
 			cache_for_files = 2048;
 			cache_for_streams = 2048;
-			time_to_kill_mplayer = 1000;
+			//time_to_kill_mplayer = 1000;
 
 			resize_method = Never;
 			//move_when_dragging = false;
 		}
+		if (config_version <= 5) {
+			#ifdef Q_OS_WIN
+			if (QSysInfo::WindowsVersion < QSysInfo::WV_WINDOWS7) {
+				mplayer_bin= "mplayer/mplayer.exe";
+			}
+			#else
+			use_audio_equalizer = false;
+			initial_volnorm = false;
+			#endif
+		}
 		config_version = CURRENT_CONFIG_VERSION;
 	}
 #endif
@@ -1840,20 +1945,25 @@ void Preferences::load() {
 		}
 	}
 	#endif
-	#ifdef Q_OS_LINUX
+	#ifdef OS_UNIX_NOT_MAC
 	if (!QFile::exists(mplayer_bin)) {
-		QString app_path = Helper::findExecutable(mplayer_bin);
+		/*
+		QString player = "mpv";
+		if (mplayer_bin.contains("mplayer")) player = "mplayer";
+		*/
+		QString player = QFileInfo(mplayer_bin).fileName();
+		QString app_path = Helper::findExecutable(player);
 		//qDebug("Preferences::load: app_path: %s", app_path.toUtf8().constData());
 		if (!app_path.isEmpty()) {
 			mplayer_bin = app_path;
 		} else {
 			// Executable not found, try to find an alternative
-			if (mplayer_bin.startsWith("mplayer")) {
+			if (mplayer_bin.contains("mplayer")) {
 				app_path = Helper::findExecutable("mpv");
 				if (!app_path.isEmpty()) mplayer_bin = app_path;
 			}
 			else
-			if (mplayer_bin.startsWith("mpv")) {
+			if (mplayer_bin.contains("mpv")) {
 				app_path = Helper::findExecutable("mplayer");
 				if (!app_path.isEmpty()) mplayer_bin = app_path;
 			}
